# <div align="center"> OpenMSIStream </div>
#### <div align="center">***v0.9.6***</div>

#### <div align="center">Maggie Eminizer<sup>1</sup>, Sam Tabrisky<sup>2,3,4</sup>, Amir Sharifzadeh<sup>1</sup>, Chris DiMarco<sup>4</sup>, Jake Diamond<sup>4</sup>, KT Ramesh<sup>4</sup>, Todd Hufnagel<sup>4,5,6</sup>, Tyrel McQueen<sup>5,7,8</sup>, David Elbert<sup>4,9</sup></div>

 <div align="center"><sup>1</sup> Institute for Data Intensive Engineering and Science (IDIES), The Johns Hopkins University, Baltimore, MD, USA </div>
 <div align="center"><sup>2</sup> Department of Biology, Dartmouth College, Hanover, NH, USA </div>
 <div align="center"><sup>3</sup> Department of Computer Science, Dartmouth College, Hanover, NH, USA </div>
 <div align="center"><sup>4</sup> Hopkins Extreme Materials Institute (HEMI), The Johns Hopkins University, Baltimore, MD, USA </div>
 <div align="center"><sup>5</sup> Department of Materials Science and Engineering, The Johns Hopkins University, Baltimore, MD, USA </div>
 <div align="center"><sup>6</sup> Department of Mechanical Engineering, The Johns Hopkins University, Baltimore, MD, USA </div>
 <div align="center"><sup>7</sup> Department of Chemistry, The Johns Hopkins University, Baltimore, MD, USA </div>
 <div align="center"><sup>8</sup> Institute for Quantum Matter (IQM), The Johns Hopkins University, Baltimore, MD, USA </div>
 <div align="center"><sup>9</sup> Department of Earth and Planetary Sciences, The Johns Hopkins University, Baltimore, MD, USA </div>

 <br>
 <div align="center"><img src="docs/source/images/openmsistream_logo.png" width="350" /></div>
 <br>

![PyPI](https://img.shields.io/pypi/v/openmsistream) ![GitHub](https://img.shields.io/github/license/openmsi/openmsistream) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/openmsistream) ![GitHub Release Date](https://img.shields.io/github/release-date/openmsi/openmsistream) ![GitHub last commit](https://img.shields.io/github/last-commit/openmsi/openmsistream) ![CircleCI](https://img.shields.io/circleci/build/github/openmsi/openmsistream/main) [![Documentation Status](https://readthedocs.org/projects/openmsistream/badge/?version=latest)](https://openmsistream.readthedocs.io/en/latest/?badge=latest) [![linting: pylint](https://img.shields.io/badge/linting-pylint-yellowgreen)](https://github.com/PyCQA/pylint)

Applications for laboratory, analysis, and computational materials data streaming using [Apache Kafka](https://kafka.apache.org/)

Available on PyPI at https://pypi.org/project/openmsistream and GitHub at https://github.com/openmsi/openmsistream 

Official documentation at https://openmsistream.readthedocs.io/en/latest/

Developed for Open MSI (NSF DMREF award #1921959)
